"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processPartialResponse = void 0;
const errors_1 = require("./errors");
/**
 * Higher level function to handle batch event processing
 * @param event Lambda's original event
 * @param recordHandler Callable function to process each record from the batch
 * @param processor Batch processor to handle partial failure cases
 * @param options Batch processing options
 * @returns Lambda Partial Batch Response
 */
const processPartialResponse = async (event, recordHandler, processor, options) => {
    if (!event.Records || !Array.isArray(event.Records)) {
        throw new errors_1.UnexpectedBatchTypeError();
    }
    processor.register(event.Records, recordHandler, options);
    await processor.process();
    return processor.response();
};
exports.processPartialResponse = processPartialResponse;
